@@ -613,7 +613,7 @@ Description: satisfy autopkgtest test dependencies
                                    'Retrying with using all packages from %s' % release)
                     self.check_exec(['/bin/sh', '-ec', 'rm /etc/apt/preferences.d/autopkgtest-' + release])
                     if not self.apt_pin_for_releases:
-                        self.check_exec(['/bin/sh', '-ec', 'rm -f /etc/apt/apt.conf.d/autopkgtest-default-release'])
+                        self.check_exec(['/bin/sh', '-ec', 'rm -f /etc/apt/preferences.d/autopkgtest-default-release'])
                     continue
 
                 if shell_on_failure:
@@ -1271,10 +1271,18 @@ fi
         return self.default_release
 
     def _set_default_release(self):
-        '''Set APT::Default-Release to enable pinning to do it's job.'''
-        script = 'mkdir -p /etc/apt/apt.conf.d; '
-        script += 'printf "APT::Default-Release \\"%(default)s\\";\\n" > /etc/apt/apt.conf.d/autopkgtest-default-release; ' % \
-            {'default': self._get_default_release()}
+        '''Set apt's default release to enable pinning to do its job.'''
+        script = 'mkdir -p /etc/apt/preferences.d; '
+        # Bug 894094: in the case pockets are used, the default release has the
+        # same code name as the pocket being tested. Therefore force the use of
+        # the archive name to distinguish the two. In general, the default
+        # release can be specified by either the code name or the archive name.
+        if self.add_apt_pockets:
+            script += 'printf "Package: *\\nPin: release a=%(default)s\\nPin-Priority: 990\\n" > /etc/apt/preferences.d/autopkgtest-default-release' % \
+                {'default': self._get_default_release()}
+        else:
+            script += 'printf "Package: *\\nPin: release %(default)s\\nPin-Priority: 990\\n" > /etc/apt/preferences.d/autopkgtest-default-release' % \
+                {'default': self._get_default_release()}
         self.check_exec(['sh', '-ec', script])
 
     def _add_apt_source(self, source, filename='autopkgtest-add-apt-sources.list'):
